@@ -18,11 +18,11 @@ Plugtools - LDAP and Posix
 
 =head1 VERSION
 
-Version 1.1.0
+Version 1.2.0
 
 =cut
 
-our $VERSION = '1.1.0';
+our $VERSION = '1.2.0';
 
 
 =head1 SYNOPSIS
@@ -643,6 +643,20 @@ sub deleteGroup{
 		return undef;
 	}
 
+	#call a plugin if needed
+	if (defined($self->{ini}->{''}->{pluginDeleteGroup})) {
+		$self->plugin({
+					   ldap=>$ldap,
+					   entry=>$entry,
+					   do=>'pluginDeleteGroup',
+					   },
+					  \%args);
+		if ($self->{error}) {
+			warn('Plugtools deleteGroup: plugin errored');
+			return undef;
+		}
+	}
+
 	#delete the entry
 	$entry->delete();
 	$mesg=$entry->update($ldap);
@@ -777,6 +791,21 @@ sub deleteUser{
 		}
 	}
 
+	#call a plugin if needed
+	if (defined($self->{ini}->{''}->{pluginDeleteUser})) {
+		$self->plugin({
+					   ldap=>$ldap,
+					   entry=>$entry,
+					   do=>'pluginDeleteUser',
+					   },
+					  \%args);
+		if ($self->{error}) {
+			warn('Plugtools deleteUser: plugin errored');
+			return undef;
+		}
+	}
+
+
 	#delete the entry
 	$entry->delete();
 	$mesg=$entry->update($ldap);
@@ -3103,6 +3132,14 @@ A comma seperated list of plugins to run when userGIDchange is called.
 
 A comma seperated list of plugins to run when userUIDchange is called.
 
+=head2 pluginDeleteUser
+
+A comma seperated list of plugins to run when deleteUser is called.
+
+=head2 pluginDeleteGroup
+
+A comma seperated list of plugins to run when deleteGroup is called.
+
 =head1 PLUGINS
 
 Plugins are supported by the functions specified in the config section.
